// import { Events } from 'util/events';
// import { StartProfiler } from 'comp/app/start-profiler';
// import { RuntimeInfo } from 'const/runtime-info';
import { Logger } from 'util/logger';
import { noop } from 'util/fn';
import * as electron from 'electron';
import { DesktopIpcRendererEvents, DesktopIpcMainEvents, DesktopIpcMainCalls } from './desktop-ipc';

const logger = new Logger('launcher');

type TypedIpcRenderer = {
    on<EventName extends keyof DesktopIpcRendererEvents>(
        event: EventName,
        listener: (
            event: electron.IpcRendererEvent,
            ...args: Parameters<DesktopIpcRendererEvents[EventName]>
        ) => void
    ): void;

    send<EventName extends keyof DesktopIpcMainEvents>(
        event: EventName,
        ...args: Parameters<DesktopIpcMainEvents[EventName]>
    ): void;

    invoke<CallName extends keyof DesktopIpcMainCalls>(
        method: CallName,
        ...args: Parameters<DesktopIpcMainCalls[CallName]>
    ): Promise<ReturnType<DesktopIpcMainCalls[CallName]>>;
};

export class LauncherElectron {
    name = 'electron';
    version = process.versions.electron;
    pendingUpdateFile?: string;
    mainWindowMaximized?: boolean;

    constructor() {
        this.ipcRenderer.on('log', (e, name, level, ...args) => {
            const logger = new Logger(name);
            logger[level](...args);
        });
    }

    get ipcRenderer(): TypedIpcRenderer {
        return electron.ipcRenderer as TypedIpcRenderer;
    }

    openLink(href: string): void {
        if (/^(http|https|ftp|sftp|mailto):/i.test(href)) {
            electron.shell.openExternal(href).catch(noop);
        }
    }

    // openDevTools() {
    //     this.electron().remote.getCurrentWindow().webContents.openDevTools({ mode: 'bottom' });
    // }
    // getSaveFileName(defaultPath, callback) {
    //     if (defaultPath) {
    //         const homePath = this.remReq('electron').app.getPath('userDesktop');
    //         defaultPath = this.joinPath(homePath, defaultPath);
    //     }
    //     this.remReq('electron')
    //         .dialog.showSaveDialog({
    //             title: Locale.launcherSave,
    //             defaultPath,
    //             filters: [{ name: Locale.launcherFileFilter, extensions: ['kdbx'] }]
    //         })
    //         .then((res) => callback(res.filePath));
    // },
    // getUserDataPath(fileName) {
    //     if (!this.userDataPath) {
    //         this.userDataPath = this.remoteApp().getPath('userData');
    //     }
    //     return this.joinPath(this.userDataPath, fileName || '');
    // },
    // getTempPath(fileName) {
    //     let tempPath = this.joinPath(this.remoteApp().getPath('temp'), 'KeeWeb');
    //     const fs = this.req('fs');
    //     if (!fs.existsSync(tempPath)) {
    //         fs.mkdirSync(tempPath);
    //     }
    //     if (fileName) {
    //         tempPath = this.joinPath(tempPath, fileName);
    //     }
    //     return tempPath;
    // },
    // getDocumentsPath(fileName) {
    //     return this.joinPath(this.remoteApp().getPath('documents'), fileName || '');
    // },
    // getAppPath(fileName) {
    //     const dirname = this.req('path').dirname;
    //     const appPath = __dirname.endsWith('app.asar') ? __dirname : this.remoteApp().getAppPath();
    //     return this.joinPath(dirname(appPath), fileName || '');
    // },
    // getWorkDirPath(fileName) {
    //     return this.joinPath(process.cwd(), fileName || '');
    // },
    // joinPath(...parts) {
    //     return this.req('path').join(...parts);
    // },
    // writeFile(path, data, callback) {
    //     this.req('fs').writeFile(path, window.Buffer.from(data), callback);
    // },
    // readFile(path, encoding, callback) {
    //     this.req('fs').readFile(path, encoding, (err, contents) => {
    //         const data = typeof contents === 'string' ? contents : new Uint8Array(contents);
    //         callback(data, err);
    //     });
    // },
    // fileExists(path, callback) {
    //     const fs = this.req('fs');
    //     fs.access(path, fs.constants.F_OK, (err) => callback(!err));
    // },
    // fileExistsSync(path) {
    //     const fs = this.req('fs');
    //     return !fs.accessSync(path, fs.constants.F_OK);
    // },
    // deleteFile(path, callback) {
    //     this.req('fs').unlink(path, callback || noop);
    // },
    // statFile(path, callback) {
    //     this.req('fs').stat(path, (err, stats) => callback(stats, err));
    // },
    // mkdir(dir, callback) {
    //     const fs = this.req('fs');
    //     const path = this.req('path');
    //     const stack = [];
    //
    //     const collect = function (dir, stack, callback) {
    //         fs.exists(dir, (exists) => {
    //             if (exists) {
    //                 return callback();
    //             }
    //
    //             stack.unshift(dir);
    //             const newDir = path.dirname(dir);
    //             if (newDir === dir || !newDir || newDir === '.' || newDir === '/') {
    //                 return callback();
    //             }
    //
    //             collect(newDir, stack, callback);
    //         });
    //     };
    //
    //     const create = function (stack, callback) {
    //         if (!stack.length) {
    //             return callback();
    //         }
    //
    //         fs.mkdir(stack.shift(), (err) => (err ? callback(err) : create(stack, callback)));
    //     };
    //
    //     collect(dir, stack, () => create(stack, callback));
    // },
    // parsePath(fileName) {
    //     const path = this.req('path');
    //     return {
    //         path: fileName,
    //         dir: path.dirname(fileName),
    //         file: path.basename(fileName)
    //     };
    // },
    // createFsWatcher(path) {
    //     return this.req('fs').watch(path, { persistent: false });
    // },
    // preventExit(e) {
    //     e.returnValue = false;
    //     return false;
    // },
    // exit() {
    //     this.exitRequested = true;
    //     this.requestExit();
    // },

    requestExit(): void {
        throw new Error('TODO');
        // const app = this.remoteApp();
        // app.setHookBeforeQuitEvent(false);
        // if (this.pendingUpdateFile) {
        //     app.restartAndUpdate(this.pendingUpdateFile);
        // } else {
        //     app.quit();
        // }
    }

    requestRestartAndUpdate(updateFilePath: string): void {
        this.pendingUpdateFile = updateFilePath;
        this.requestExit();
    }

    // cancelRestart() {
    //     this.pendingUpdateFile = undefined;
    // },

    setClipboardText(text: string): void {
        electron.clipboard.writeText(text);
    }

    getClipboardText(): string {
        return electron.clipboard.readText();
    }

    clearClipboardText(): void {
        electron.clipboard.clear();
        if (process.platform === 'linux') {
            electron.clipboard.clear('selection');
        }
    }

    // quitOnRealQuitEventIfMinimizeOnQuitIsEnabled() {
    //     return !!this.pendingUpdateFile;
    // },
    // minimizeApp() {
    //     this.remoteApp().minimizeApp({
    //         restore: Locale.menuRestoreApp.replace('{}', 'KeeWeb'),
    //         quit: Locale.menuQuitApp.replace('{}', 'KeeWeb')
    //     });
    // },
    // canDetectOsSleep() {
    //     return process.platform !== 'linux';
    // },

    updaterEnabled(): boolean {
        return process.platform !== 'linux';
    }

    // getMainWindow() {
    //     return this.remoteApp().getMainWindow();
    // },
    // resolveProxy(url, callback) {
    //     const window = this.getMainWindow();
    //     const session = window.webContents.session;
    //     session.resolveProxy(url).then((proxy) => {
    //         const match = /^proxy\s+([\w\.]+):(\d+)+\s*/i.exec(proxy);
    //         proxy = match && match[1] ? { host: match[1], port: +match[2] } : null;
    //         callback(proxy);
    //     });
    // },
    // hideApp() {
    //     const app = this.remoteApp();
    //     if (this.platform() === 'darwin') {
    //         app.hide();
    //     } else {
    //         app.minimizeThenHideIfInTray();
    //     }
    // },
    // isAppFocused() {
    //     return !!this.electron().remote.BrowserWindow.getFocusedWindow();
    // },
    // showMainWindow() {
    //     this.remoteApp().showAndFocusMainWindow();
    // },

    async spawn(config: {
        cmd: string;
        args: string[];
        noStdOutLogging?: boolean;
        throwOnStdErr?: boolean;
        name?: string;
    }): Promise<{ code?: number; stdout?: string; stderr?: string }> {
        const ts = logger.ts();
        const res = await this.ipcRenderer.invoke('spawn-process', {
            cmd: config.cmd,
            args: config.args
        });
        if (res.err) {
            logger.error('spawn error: ' + config.cmd + ', ' + logger.ts(ts), res.err);
            throw new Error(res.err);
        } else {
            const msg = `spawn ${config.cmd}: ${res.code || 0}, ${logger.ts(ts)}`;
            if (res.code) {
                logger.error(`${msg}\n${res.stdout ?? ''}\n${res.stderr ?? ''}`);
                throw new Error(`Exit code ${res.code}`);
            } else {
                logger.info(msg + (res.stdout && !config.noStdOutLogging ? '\n' + res.stdout : ''));
                if (res.stderr && config.throwOnStdErr) {
                    throw new Error(`Error returned: ${res.stderr.trim()}`);
                }
            }
            return res;
        }
    }

    async killProcess(name: string): Promise<void> {
        await this.ipcRenderer.invoke('kill-process', name);
    }

    // checkOpenFiles() {
    //     this.readyToOpenFiles = true;
    //     if (this.pendingFileToOpen) {
    //         this.openFile(this.pendingFileToOpen);
    //         delete this.pendingFileToOpen;
    //     }
    // },
    // openFile(file) {
    //     if (this.readyToOpenFiles) {
    //         Events.emit('launcher-open-file', file);
    //     } else {
    //         this.pendingFileToOpen = file;
    //     }
    // },
    // minimizeMainWindow() {
    //     this.getMainWindow().minimize();
    // },
    // maximizeMainWindow() {
    //     this.getMainWindow().maximize();
    // },
    // restoreMainWindow() {
    //     this.getMainWindow().restore();
    // },
    // mainWindowMaximized() {
    //     return this.getMainWindow().isMaximized();
    // }
}

// Events.on('launcher-exit-request', () => {
//     setTimeout(() => Launcher.exit(), 0);
// });
// Events.on('launcher-minimize', () => setTimeout(() => Events.emit('app-minimized'), 0));
// Events.on('launcher-maximize', () => setTimeout(() => Events.emit('app-maximized'), 0));
// Events.on('launcher-unmaximize', () => setTimeout(() => Events.emit('app-unmaximized'), 0));
// Events.on('launcher-started-minimized', () => setTimeout(() => Launcher.minimizeApp(), 0));
// Events.on('start-profile', (data) => StartProfiler.reportAppProfile(data));
//
// window.launcherOpen = (file) => Launcher.openFile(file);
// if (window.launcherOpenedFile) {
//     logger.info('Open file request', window.launcherOpenedFile);
//     Launcher.openFile(window.launcherOpenedFile);
//     delete window.launcherOpenedFile;
// }
// Events.on('app-ready', () =>
//     setTimeout(() => {
//         Launcher.checkOpenFiles();
//         Launcher.remoteApp().setAboutPanelOptions({
//             applicationVersion: RuntimeInfo.version,
//             version: RuntimeInfo.commit
//         });
//     }, 0)
// );
//
// if (process.platform === 'darwin') {
//     Launcher.remoteApp().setHookBeforeQuitEvent(true);
// }
//
// Launcher.remoteApp().on('remote-app-event', (e) => {
//     if (window.debugRemoteAppEvents) {
//         logger.info('remote-app-event', e.name);
//     }
//     Events.emit(e.name, e.data);
// });
