const BaseLocale = require('locales/base.json') as Record<string, string>;
const BaseLocaleName = 'en-US';

export interface LocWithReplace {
    with(value: string): string;
}

let activeLocale: Record<string, string> | undefined;
let activeLocaleName = BaseLocaleName;

function set(values: Record<string, string>, localeName: string): void;
function set(values: undefined): void;
function set(values?: Record<string, string>, localeName?: string): void {
    activeLocale = values;
    activeLocaleName = localeName ?? BaseLocaleName;
}

function get(name: string): string {
    return activeLocale?.[name] ?? BaseLocale[name] ?? '';
}

function withReplace(name: string): LocWithReplace {
    return { with: (repl) => get(name).replace('{}', repl) };
}

// prettier-ignore
export const Locale = {
    set,
    // get,
    get localeName(): string { return activeLocaleName; },

    // this code is generated using npm run generate-locale
    get retToApp(): string { return get('retToApp'); },
    get name(): string { return get('name'); },
    get icon(): string { return get('icon'); },
    get title(): string { return get('title'); },
    get password(): string { return get('password'); },
    get user(): string { return get('user'); },
    get website(): string { return get('website'); },
    get tags(): string { return get('tags'); },
    get notes(): string { return get('notes'); },
    get entry(): string { return get('entry'); },
    get group(): string { return get('group'); },
    get noTitle(): string { return get('noTitle'); },
    get or(): string { return get('or'); },
    get history(): string { return get('history'); },
    get template(): string { return get('template'); },
    get templates(): string { return get('templates'); },
    get notImplemented(): string { return get('notImplemented'); },
    get saveChanges(): string { return get('saveChanges'); },
    get discardChanges(): string { return get('discardChanges'); },
    get advanced(): string { return get('advanced'); },
    get shortcuts(): string { return get('shortcuts'); },
    get help(): string { return get('help'); },
    get settings(): string { return get('settings'); },
    get plugins(): string { return get('plugins'); },
    get ctrlKey(): string { return get('ctrlKey'); },
    get shiftKey(): string { return get('shiftKey'); },
    get altKey(): string { return get('altKey'); },
    get error(): string { return get('error'); },
    get oneMinute(): string { return get('oneMinute'); },
    minutes: withReplace('minutes'),
    get oneHour(): string { return get('oneHour'); },
    hours: withReplace('hours'),
    get oneDay(): string { return get('oneDay'); },
    days: withReplace('days'),
    get oneWeek(): string { return get('oneWeek'); },
    get oneMonth(): string { return get('oneMonth'); },
    get oneYear(): string { return get('oneYear'); },
    get cache(): string { return get('cache'); },
    get file(): string { return get('file'); },
    get device(): string { return get('device'); },
    get webdav(): string { return get('webdav'); },
    get dropbox(): string { return get('dropbox'); },
    get gdrive(): string { return get('gdrive'); },
    get onedrive(): string { return get('onedrive'); },
    get menuAllItems(): string { return get('menuAllItems'); },
    get menuColors(): string { return get('menuColors'); },
    get menuTrash(): string { return get('menuTrash'); },
    get menuSetGeneral(): string { return get('menuSetGeneral'); },
    get menuSetBrowser(): string { return get('menuSetBrowser'); },
    get menuSetAbout(): string { return get('menuSetAbout'); },
    get menuSetDevices(): string { return get('menuSetDevices'); },
    get menuAlertNoTags(): string { return get('menuAlertNoTags'); },
    get menuAlertNoTagsBody(): string { return get('menuAlertNoTagsBody'); },
    get menuEmptyTrash(): string { return get('menuEmptyTrash'); },
    get menuEmptyTrashAlert(): string { return get('menuEmptyTrashAlert'); },
    get menuEmptyTrashAlertBody(): string { return get('menuEmptyTrashAlertBody'); },
    get menuItemCollapsed(): string { return get('menuItemCollapsed'); },
    menuRestoreApp: withReplace('menuRestoreApp'),
    menuQuitApp: withReplace('menuQuitApp'),
    sysMenuAboutKeeWeb: withReplace('sysMenuAboutKeeWeb'),
    get sysMenuServices(): string { return get('sysMenuServices'); },
    sysMenuHide: withReplace('sysMenuHide'),
    get sysMenuHideOthers(): string { return get('sysMenuHideOthers'); },
    get sysMenuUnhide(): string { return get('sysMenuUnhide'); },
    sysMenuQuit: withReplace('sysMenuQuit'),
    get sysMenuEdit(): string { return get('sysMenuEdit'); },
    get sysMenuUndo(): string { return get('sysMenuUndo'); },
    get sysMenuRedo(): string { return get('sysMenuRedo'); },
    get sysMenuCut(): string { return get('sysMenuCut'); },
    get sysMenuCopy(): string { return get('sysMenuCopy'); },
    get sysMenuPaste(): string { return get('sysMenuPaste'); },
    get sysMenuSelectAll(): string { return get('sysMenuSelectAll'); },
    get sysMenuWindow(): string { return get('sysMenuWindow'); },
    get sysMenuMinimize(): string { return get('sysMenuMinimize'); },
    get sysMenuClose(): string { return get('sysMenuClose'); },
    get alertYes(): string { return get('alertYes'); },
    get alertNo(): string { return get('alertNo'); },
    get alertOk(): string { return get('alertOk'); },
    get alertCancel(): string { return get('alertCancel'); },
    get alertSignIn(): string { return get('alertSignIn'); },
    get alertCopy(): string { return get('alertCopy'); },
    get alertClose(): string { return get('alertClose'); },
    get alertDoNotAsk(): string { return get('alertDoNotAsk'); },
    get alertAllow(): string { return get('alertAllow'); },
    get alertDeny(): string { return get('alertDeny'); },
    get appBeta(): string { return get('appBeta'); },
    get footerOpen(): string { return get('footerOpen'); },
    get footerSyncError(): string { return get('footerSyncError'); },
    get footerTitleGen(): string { return get('footerTitleGen'); },
    get footerTitleLock(): string { return get('footerTitleLock'); },
    get genLen(): string { return get('genLen'); },
    get genNewPass(): string { return get('genNewPass'); },
    get genPresetDefault(): string { return get('genPresetDefault'); },
    get genPresetDerived(): string { return get('genPresetDerived'); },
    get genPresetPronounceable(): string { return get('genPresetPronounceable'); },
    get genPresetMed(): string { return get('genPresetMed'); },
    get genPresetLong(): string { return get('genPresetLong'); },
    get genPresetPin4(): string { return get('genPresetPin4'); },
    get genPresetMac(): string { return get('genPresetMac'); },
    get genPresetHash128(): string { return get('genPresetHash128'); },
    get genPresetHash256(): string { return get('genPresetHash256'); },
    get genHidePass(): string { return get('genHidePass'); },
    get genShowPass(): string { return get('genShowPass'); },
    get grpTitle(): string { return get('grpTitle'); },
    get grpSearch(): string { return get('grpSearch'); },
    get grpAutoType(): string { return get('grpAutoType'); },
    get grpAutoTypeSeq(): string { return get('grpAutoTypeSeq'); },
    get grpAutoTypeSeqDefault(): string { return get('grpAutoTypeSeqDefault'); },
    get grpTrash(): string { return get('grpTrash'); },
    get tagTitle(): string { return get('tagTitle'); },
    get tagTrash(): string { return get('tagTrash'); },
    get tagRename(): string { return get('tagRename'); },
    get tagTrashQuestion(): string { return get('tagTrashQuestion'); },
    get tagTrashQuestionBody(): string { return get('tagTrashQuestionBody'); },
    get tagExists(): string { return get('tagExists'); },
    get tagExistsBody(): string { return get('tagExistsBody'); },
    get tagBadName(): string { return get('tagBadName'); },
    tagBadNameBody: withReplace('tagBadNameBody'),
    get genPsTitle(): string { return get('genPsTitle'); },
    get genPsCreate(): string { return get('genPsCreate'); },
    get genPsDelete(): string { return get('genPsDelete'); },
    get genPsNew(): string { return get('genPsNew'); },
    get genPsEnabled(): string { return get('genPsEnabled'); },
    get genPsDefault(): string { return get('genPsDefault'); },
    get genPsDefaultLength(): string { return get('genPsDefaultLength'); },
    get genPsUpper(): string { return get('genPsUpper'); },
    get genPsLower(): string { return get('genPsLower'); },
    get genPsDigits(): string { return get('genPsDigits'); },
    get genPsSpecial(): string { return get('genPsSpecial'); },
    get genPsBrackets(): string { return get('genPsBrackets'); },
    get genPsHigh(): string { return get('genPsHigh'); },
    get genPsAmbiguous(): string { return get('genPsAmbiguous'); },
    get genPsInclude(): string { return get('genPsInclude'); },
    get genPsExample(): string { return get('genPsExample'); },
    get genPsPattern(): string { return get('genPsPattern'); },
    get genPsPatternHelp(): string { return get('genPsPatternHelp'); },
    get genPsAllRanges(): string { return get('genPsAllRanges'); },
    get genPsIncluded(): string { return get('genPsIncluded'); },
    get keyChangeTitleRemote(): string { return get('keyChangeTitleRemote'); },
    get keyChangeMessageRemote(): string { return get('keyChangeMessageRemote'); },
    get keyChangeTitleExpired(): string { return get('keyChangeTitleExpired'); },
    get keyChangeMessageExpired(): string { return get('keyChangeMessageExpired'); },
    get keyChangeRepeatPassword(): string { return get('keyChangeRepeatPassword'); },
    get keyEnter(): string { return get('keyEnter'); },
    get keyEsc(): string { return get('keyEsc'); },
    get iconFavTitle(): string { return get('iconFavTitle'); },
    get iconSelCustom(): string { return get('iconSelCustom'); },
    get listEmptyTitle(): string { return get('listEmptyTitle'); },
    listEmptyAdd: withReplace('listEmptyAdd'),
    get listGroup(): string { return get('listGroup'); },
    get listNoWebsite(): string { return get('listNoWebsite'); },
    get listNoUser(): string { return get('listNoUser'); },
    get listNoAttachments(): string { return get('listNoAttachments'); },
    get listAddTemplateHeader(): string { return get('listAddTemplateHeader'); },
    listAddTemplateBody1: withReplace('listAddTemplateBody1'),
    listAddTemplateBody2: withReplace('listAddTemplateBody2'),
    get searchAddNew(): string { return get('searchAddNew'); },
    get searchSort(): string { return get('searchSort'); },
    get searchCreated(): string { return get('searchCreated'); },
    get searchUpdated(): string { return get('searchUpdated'); },
    get searchAttachments(): string { return get('searchAttachments'); },
    searchAZ: withReplace('searchAZ'),
    searchZA: withReplace('searchZA'),
    searchON: withReplace('searchON'),
    searchNO: withReplace('searchNO'),
    get searchShiftClickOr(): string { return get('searchShiftClickOr'); },
    get searchAdvTitle(): string { return get('searchAdvTitle'); },
    get searchSearchIn(): string { return get('searchSearchIn'); },
    get searchOther(): string { return get('searchOther'); },
    get searchProtect(): string { return get('searchProtect'); },
    get searchOptions(): string { return get('searchOptions'); },
    get searchCase(): string { return get('searchCase'); },
    get searchRegex(): string { return get('searchRegex'); },
    get searchRank(): string { return get('searchRank'); },
    get searchExact(): string { return get('searchExact'); },
    get openOpen(): string { return get('openOpen'); },
    get openNew(): string { return get('openNew'); },
    get openNewFile(): string { return get('openNewFile'); },
    get openMore(): string { return get('openMore'); },
    get openDemo(): string { return get('openDemo'); },
    get openGenerate(): string { return get('openGenerate'); },
    get openXml(): string { return get('openXml'); },
    get openCaps(): string { return get('openCaps'); },
    get openClickToOpen(): string { return get('openClickToOpen'); },
    get openKeyFile(): string { return get('openKeyFile'); },
    get openKeyFileDropbox(): string { return get('openKeyFileDropbox'); },
    get openDropHere(): string { return get('openDropHere'); },
    get openFailedRead(): string { return get('openFailedRead'); },
    get openNothingFound(): string { return get('openNothingFound'); },
    get openNothingFoundBody(): string { return get('openNothingFoundBody'); },
    get openSelectFile(): string { return get('openSelectFile'); },
    get openSelectFileBody(): string { return get('openSelectFileBody'); },
    get openPassFor(): string { return get('openPassFor'); },
    get openRemoveLastQuestion(): string { return get('openRemoveLastQuestion'); },
    get openRemoveLastQuestionBody(): string { return get('openRemoveLastQuestionBody'); },
    get openRemoveLastQuestionModBody(): string { return get('openRemoveLastQuestionModBody'); },
    get openLocalFile(): string { return get('openLocalFile'); },
    get openLocalFileBody(): string { return get('openLocalFileBody'); },
    get openLocalFileDontShow(): string { return get('openLocalFileDontShow'); },
    get openWrongFile(): string { return get('openWrongFile'); },
    get openWrongFileBody(): string { return get('openWrongFileBody'); },
    get openKdbFileBody(): string { return get('openKdbFileBody'); },
    openConfigHeader: withReplace('openConfigHeader'),
    get openUrl(): string { return get('openUrl'); },
    get openUrlDesc(): string { return get('openUrlDesc'); },
    get openUser(): string { return get('openUser'); },
    get openUserDesc(): string { return get('openUserDesc'); },
    get openUserPlaceholder(): string { return get('openUserPlaceholder'); },
    get openPass(): string { return get('openPass'); },
    get openPassDesc(): string { return get('openPassDesc'); },
    get openPassPlaceholder(): string { return get('openPassPlaceholder'); },
    openConfigError: withReplace('openConfigError'),
    get openConfigErrorNotFound(): string { return get('openConfigErrorNotFound'); },
    get openError(): string { return get('openError'); },
    get openErrorDescription(): string { return get('openErrorDescription'); },
    get openErrorDescriptionMaybeTouchIdChanged(): string { return get('openErrorDescriptionMaybeTouchIdChanged'); },
    get openErrorFileNotFound(): string { return get('openErrorFileNotFound'); },
    get openListErrorBody(): string { return get('openListErrorBody'); },
    get openShowAllFiles(): string { return get('openShowAllFiles'); },
    get openFileNoCacheError(): string { return get('openFileNoCacheError'); },
    get openChalRespHeader(): string { return get('openChalRespHeader'); },
    get openChalRespLoading(): string { return get('openChalRespLoading'); },
    get openChalRespSelectYubiKey(): string { return get('openChalRespSelectYubiKey'); },
    get openChalRespErrorEmpty(): string { return get('openChalRespErrorEmpty'); },
    get openChalRespErrorEmptyMac(): string { return get('openChalRespErrorEmptyMac'); },
    get detAttDownload(): string { return get('detAttDownload'); },
    get detAttDelToRemove(): string { return get('detAttDelToRemove'); },
    get detAttSave(): string { return get('detAttSave'); },
    get detEmpty(): string { return get('detEmpty'); },
    get detGroupRestore(): string { return get('detGroupRestore'); },
    get detHistoryClickPoint(): string { return get('detHistoryClickPoint'); },
    get detHistoryReturn(): string { return get('detHistoryReturn'); },
    get detHistoryRevert(): string { return get('detHistoryRevert'); },
    get detHistoryDel(): string { return get('detHistoryDel'); },
    get detHistoryEmpty(): string { return get('detHistoryEmpty'); },
    get detHistoryModified(): string { return get('detHistoryModified'); },
    get detHistoryRec(): string { return get('detHistoryRec'); },
    get detHistoryRecs(): string { return get('detHistoryRecs'); },
    get detHistoryVersion(): string { return get('detHistoryVersion'); },
    get detHistorySaved(): string { return get('detHistorySaved'); },
    get detHistoryNoTitle(): string { return get('detHistoryNoTitle'); },
    get detHistoryCurState(): string { return get('detHistoryCurState'); },
    get detHistoryCurUnsavedState(): string { return get('detHistoryCurUnsavedState'); },
    get detHistoryRevertAlert(): string { return get('detHistoryRevertAlert'); },
    get detHistoryRevertAlertBody(): string { return get('detHistoryRevertAlertBody'); },
    get detHistoryDeleteAlert(): string { return get('detHistoryDeleteAlert'); },
    get detHistoryDeleteAlertBody(): string { return get('detHistoryDeleteAlertBody'); },
    get detHistoryDiscardChangesAlert(): string { return get('detHistoryDiscardChangesAlert'); },
    get detHistoryDiscardChangesAlertBody(): string { return get('detHistoryDiscardChangesAlertBody'); },
    get detBackToList(): string { return get('detBackToList'); },
    get detSetIconColor(): string { return get('detSetIconColor'); },
    get detSetIcon(): string { return get('detSetIcon'); },
    get detDropAttachments(): string { return get('detDropAttachments'); },
    get detDelEntry(): string { return get('detDelEntry'); },
    get detDelEntryPerm(): string { return get('detDelEntryPerm'); },
    get detExpires(): string { return get('detExpires'); },
    get detExpired(): string { return get('detExpired'); },
    get detGroup(): string { return get('detGroup'); },
    get detCreated(): string { return get('detCreated'); },
    get detUpdated(): string { return get('detUpdated'); },
    get detNetField(): string { return get('detNetField'); },
    get detAttachments(): string { return get('detAttachments'); },
    get detDelFromTrash(): string { return get('detDelFromTrash'); },
    get detDelFromTrashBody(): string { return get('detDelFromTrashBody'); },
    get detDelFromTrashBodyHint(): string { return get('detDelFromTrashBodyHint'); },
    get detDelToTrash(): string { return get('detDelToTrash'); },
    get detDelToTrashBody(): string { return get('detDelToTrashBody'); },
    get detFieldCopied(): string { return get('detFieldCopied'); },
    detFieldCopiedTime: withReplace('detFieldCopiedTime'),
    get detCopyHint(): string { return get('detCopyHint'); },
    get detMore(): string { return get('detMore'); },
    get detClickToAddField(): string { return get('detClickToAddField'); },
    get detMenuAddNewField(): string { return get('detMenuAddNewField'); },
    get detMenuAddNewWebsite(): string { return get('detMenuAddNewWebsite'); },
    get detMenuShowEmpty(): string { return get('detMenuShowEmpty'); },
    get detMenuHideEmpty(): string { return get('detMenuHideEmpty'); },
    detMenuAddField: withReplace('detMenuAddField'),
    get detMenuCopyPassword(): string { return get('detMenuCopyPassword'); },
    get detMenuCopyUser(): string { return get('detMenuCopyUser'); },
    get detMenuCopyOtp(): string { return get('detMenuCopyOtp'); },
    get detSetupOtp(): string { return get('detSetupOtp'); },
    get detClone(): string { return get('detClone'); },
    get detCopyEntryToClipboard(): string { return get('detCopyEntryToClipboard'); },
    get detClonedName(): string { return get('detClonedName'); },
    get detAutoType(): string { return get('detAutoType'); },
    get detAutoTypeSettings(): string { return get('detAutoTypeSettings'); },
    get detAutoTypeEnabled(): string { return get('detAutoTypeEnabled'); },
    get detAutoTypeSequence(): string { return get('detAutoTypeSequence'); },
    get detAutoTypeInput(): string { return get('detAutoTypeInput'); },
    detAutoTypeShortcutsDesc: withReplace('detAutoTypeShortcutsDesc'),
    get detAutoTypeObfuscation(): string { return get('detAutoTypeObfuscation'); },
    get detAutoTypeWindow(): string { return get('detAutoTypeWindow'); },
    get detAutoTypeInputWindow(): string { return get('detAutoTypeInputWindow'); },
    get detSetupOtpAlert(): string { return get('detSetupOtpAlert'); },
    get detSetupOtpAlertBody(): string { return get('detSetupOtpAlertBody'); },
    get detSetupOtpAlertBody1(): string { return get('detSetupOtpAlertBody1'); },
    detSetupOtpAlertBody2: withReplace('detSetupOtpAlertBody2'),
    detSetupOtpAlertBody3: withReplace('detSetupOtpAlertBody3'),
    get detSetupOtpAlertBody3Mobile(): string { return get('detSetupOtpAlertBody3Mobile'); },
    get detSetupOtpAlertBody4(): string { return get('detSetupOtpAlertBody4'); },
    get detSetupOtpManualButton(): string { return get('detSetupOtpManualButton'); },
    get detSetupOtpScanButton(): string { return get('detSetupOtpScanButton'); },
    detSetupOtpAlertBodyWith: withReplace('detSetupOtpAlertBodyWith'),
    get detOtpImageError(): string { return get('detOtpImageError'); },
    get detOtpImageErrorBody(): string { return get('detOtpImageErrorBody'); },
    get detOtpImageReading(): string { return get('detOtpImageReading'); },
    get detOtpQrError(): string { return get('detOtpQrError'); },
    get detOtpQrErrorBody(): string { return get('detOtpQrErrorBody'); },
    get detOtpQrWrong(): string { return get('detOtpQrWrong'); },
    get detOtpQrWrongBody(): string { return get('detOtpQrWrongBody'); },
    get detOtpField(): string { return get('detOtpField'); },
    get detOtpClickToTouch(): string { return get('detOtpClickToTouch'); },
    get detOtpGenerating(): string { return get('detOtpGenerating'); },
    detOtpTouch: withReplace('detOtpTouch'),
    get detLockField(): string { return get('detLockField'); },
    get detUnlockField(): string { return get('detUnlockField'); },
    get detRevealField(): string { return get('detRevealField'); },
    get detHideField(): string { return get('detHideField'); },
    get detAutoTypeField(): string { return get('detAutoTypeField'); },
    get detIssuesHideTooltip(): string { return get('detIssuesHideTooltip'); },
    get detIssueWeakPassword(): string { return get('detIssueWeakPassword'); },
    get detIssuePoorPassword(): string { return get('detIssuePoorPassword'); },
    detIssuePwnedPassword: withReplace('detIssuePwnedPassword'),
    get detIssuePasswordCheckError(): string { return get('detIssuePasswordCheckError'); },
    get detIssueOldPassword(): string { return get('detIssueOldPassword'); },
    get detIssueCloseAlertHeader(): string { return get('detIssueCloseAlertHeader'); },
    get detIssueCloseAlertBody(): string { return get('detIssueCloseAlertBody'); },
    get detIssueCloseAlertEntry(): string { return get('detIssueCloseAlertEntry'); },
    get detIssueCloseAlertSettings(): string { return get('detIssueCloseAlertSettings'); },
    get autoTypeEntryFields(): string { return get('autoTypeEntryFields'); },
    get autoTypeModifiers(): string { return get('autoTypeModifiers'); },
    get autoTypeKeys(): string { return get('autoTypeKeys'); },
    get autoTypeLink(): string { return get('autoTypeLink'); },
    get autoTypeError(): string { return get('autoTypeError'); },
    autoTypeErrorGeneric: withReplace('autoTypeErrorGeneric'),
    get autoTypeErrorAccessibilityMacOS(): string { return get('autoTypeErrorAccessibilityMacOS'); },
    get autoTypeErrorGlobal(): string { return get('autoTypeErrorGlobal'); },
    autoTypeErrorNotInstalled: withReplace('autoTypeErrorNotInstalled'),
    get autoTypeHeader(): string { return get('autoTypeHeader'); },
    get autoTypeMsgNoWindow(): string { return get('autoTypeMsgNoWindow'); },
    autoTypeMsgMatchedByWindow: withReplace('autoTypeMsgMatchedByWindow'),
    get autoTypeNoMatches(): string { return get('autoTypeNoMatches'); },
    get autoTypeSelectionHint(): string { return get('autoTypeSelectionHint'); },
    get autoTypeSelectionHintAction(): string { return get('autoTypeSelectionHintAction'); },
    get autoTypeSelectionHintOpt(): string { return get('autoTypeSelectionHintOpt'); },
    get autoTypeSelectionHintShift(): string { return get('autoTypeSelectionHintShift'); },
    get autoTypeSelectionOtp(): string { return get('autoTypeSelectionOtp'); },
    get autoTypeUnlockMessage(): string { return get('autoTypeUnlockMessage'); },
    get appSecWarn(): string { return get('appSecWarn'); },
    get appSecWarnBody1(): string { return get('appSecWarnBody1'); },
    get appSecWarnBody2(): string { return get('appSecWarnBody2'); },
    get appSecWarnBtn(): string { return get('appSecWarnBtn'); },
    get appUnsavedWarn(): string { return get('appUnsavedWarn'); },
    get appUnsavedWarnBody(): string { return get('appUnsavedWarnBody'); },
    get appDontExitBtn(): string { return get('appDontExitBtn'); },
    get appCannotLockAutoInit(): string { return get('appCannotLockAutoInit'); },
    get appCannotLock(): string { return get('appCannotLock'); },
    get appAutoSave(): string { return get('appAutoSave'); },
    get appSaveError(): string { return get('appSaveError'); },
    get appSaveErrorBody(): string { return get('appSaveErrorBody'); },
    get appSaveErrorBodyMul(): string { return get('appSaveErrorBodyMul'); },
    get appSaveErrorExitLoseChanges(): string { return get('appSaveErrorExitLoseChanges'); },
    get appSaveErrorExitLoseChangesBody(): string { return get('appSaveErrorExitLoseChangesBody'); },
    get appSettingsError(): string { return get('appSettingsError'); },
    get appSettingsErrorBody(): string { return get('appSettingsErrorBody'); },
    get appNotSupportedError(): string { return get('appNotSupportedError'); },
    get appTabWarn(): string { return get('appTabWarn'); },
    get appTabWarnBody(): string { return get('appTabWarnBody'); },
    get appRightsAlert(): string { return get('appRightsAlert'); },
    get appRightsAlertBody1(): string { return get('appRightsAlertBody1'); },
    get appRightsAlertBody2(): string { return get('appRightsAlertBody2'); },
    get appBrowserAuthComplete(): string { return get('appBrowserAuthComplete'); },
    get setGenTitle(): string { return get('setGenTitle'); },
    get setGenUpdate(): string { return get('setGenUpdate'); },
    get setGenNewVersion(): string { return get('setGenNewVersion'); },
    get setGenReleaseNotes(): string { return get('setGenReleaseNotes'); },
    get setGenReloadToUpdate(): string { return get('setGenReloadToUpdate'); },
    get setGenUpdateManual(): string { return get('setGenUpdateManual'); },
    get setGenDownloadUpdate(): string { return get('setGenDownloadUpdate'); },
    get setGenUpdateAuto(): string { return get('setGenUpdateAuto'); },
    get setGenUpdateCheck(): string { return get('setGenUpdateCheck'); },
    get setGenNoUpdate(): string { return get('setGenNoUpdate'); },
    get setGenUpdateChecking(): string { return get('setGenUpdateChecking'); },
    get setGenCheckUpdate(): string { return get('setGenCheckUpdate'); },
    get setGenErrorChecking(): string { return get('setGenErrorChecking'); },
    setGenLastCheckSuccess: withReplace('setGenLastCheckSuccess'),
    setGenLastCheckVer: withReplace('setGenLastCheckVer'),
    get setGenCheckedAt(): string { return get('setGenCheckedAt'); },
    get setGenLatestVer(): string { return get('setGenLatestVer'); },
    setGenNewVer: withReplace('setGenNewVer'),
    get setGenDownloadingUpdate(): string { return get('setGenDownloadingUpdate'); },
    get setGenExtractingUpdate(): string { return get('setGenExtractingUpdate'); },
    get setGenCheckErr(): string { return get('setGenCheckErr'); },
    get setGenNeverChecked(): string { return get('setGenNeverChecked'); },
    get setGenRestartToUpdate(): string { return get('setGenRestartToUpdate'); },
    get setGenDownloadAndRestart(): string { return get('setGenDownloadAndRestart'); },
    get setGenAppearance(): string { return get('setGenAppearance'); },
    get setGenTheme(): string { return get('setGenTheme'); },
    get setGenThemeDefault(): string { return get('setGenThemeDefault'); },
    get setGenThemeDark(): string { return get('setGenThemeDark'); },
    get setGenThemeLight(): string { return get('setGenThemeLight'); },
    get setGenThemeBlue(): string { return get('setGenThemeBlue'); },
    get setGenThemeFb(): string { return get('setGenThemeFb'); },
    get setGenThemeBl(): string { return get('setGenThemeBl'); },
    get setGenThemeBrown(): string { return get('setGenThemeBrown'); },
    get setGenThemeDb(): string { return get('setGenThemeDb'); },
    get setGenThemeLb(): string { return get('setGenThemeLb'); },
    get setGenThemeTerminal(): string { return get('setGenThemeTerminal'); },
    get setGenThemeTe(): string { return get('setGenThemeTe'); },
    get setGenThemeLt(): string { return get('setGenThemeLt'); },
    get setGenThemeHighContrast(): string { return get('setGenThemeHighContrast'); },
    get setGenThemeHc(): string { return get('setGenThemeHc'); },
    get setGenThemeDc(): string { return get('setGenThemeDc'); },
    get setGenThemeSol(): string { return get('setGenThemeSol'); },
    get setGenThemeSd(): string { return get('setGenThemeSd'); },
    get setGenThemeSl(): string { return get('setGenThemeSl'); },
    get setGenMoreThemes(): string { return get('setGenMoreThemes'); },
    get setGenAutoSwitchTheme(): string { return get('setGenAutoSwitchTheme'); },
    get setGenLocale(): string { return get('setGenLocale'); },
    get setGenLocOther(): string { return get('setGenLocOther'); },
    get setGenFontSize(): string { return get('setGenFontSize'); },
    get setGenFontSizeNormal(): string { return get('setGenFontSizeNormal'); },
    get setGenFontSizeLarge(): string { return get('setGenFontSizeLarge'); },
    get setGenFontSizeLargest(): string { return get('setGenFontSizeLargest'); },
    get setGenTitlebarStyle(): string { return get('setGenTitlebarStyle'); },
    get setGenTitlebarStyleDefault(): string { return get('setGenTitlebarStyleDefault'); },
    get setGenTitlebarStyleHidden(): string { return get('setGenTitlebarStyleHidden'); },
    get setGenTitlebarStyleHiddenInset(): string { return get('setGenTitlebarStyleHiddenInset'); },
    get setGenShowSubgroups(): string { return get('setGenShowSubgroups'); },
    get setGenTableView(): string { return get('setGenTableView'); },
    get setGenColorfulIcons(): string { return get('setGenColorfulIcons'); },
    get setGenUseMarkdown(): string { return get('setGenUseMarkdown'); },
    get setGenUseGroupIconForEntries(): string { return get('setGenUseGroupIconForEntries'); },
    get setGenDirectAutotype(): string { return get('setGenDirectAutotype'); },
    get setGenAutoTypeTitleFilterEnabled(): string { return get('setGenAutoTypeTitleFilterEnabled'); },
    get setGenFunction(): string { return get('setGenFunction'); },
    get setGenAutoSyncOnClose(): string { return get('setGenAutoSyncOnClose'); },
    get setGenAutoSyncTimer(): string { return get('setGenAutoSyncTimer'); },
    get setGenAutoSyncTimerOff(): string { return get('setGenAutoSyncTimerOff'); },
    get setGenAutoSyncTimerOnChange(): string { return get('setGenAutoSyncTimerOnChange'); },
    setGenAutoSyncTimerInterval: withReplace('setGenAutoSyncTimerInterval'),
    get setGenRememberKeyFiles(): string { return get('setGenRememberKeyFiles'); },
    get setGenNoRememberKeyFiles(): string { return get('setGenNoRememberKeyFiles'); },
    get setGenRememberKeyFilesData(): string { return get('setGenRememberKeyFilesData'); },
    get setGenRememberKeyFilesPath(): string { return get('setGenRememberKeyFilesPath'); },
    get setGenLockInactive(): string { return get('setGenLockInactive'); },
    get setGenNoAutoLock(): string { return get('setGenNoAutoLock'); },
    setGenLockMinutes: withReplace('setGenLockMinutes'),
    get setGenLockHour(): string { return get('setGenLockHour'); },
    setGenLockHours: withReplace('setGenLockHours'),
    get setGenLockDay(): string { return get('setGenLockDay'); },
    get setGenClearClip(): string { return get('setGenClearClip'); },
    get setGenNoClear(): string { return get('setGenNoClear'); },
    setGenClearSeconds: withReplace('setGenClearSeconds'),
    get setGenClearMinute(): string { return get('setGenClearMinute'); },
    get setGenMinInstead(): string { return get('setGenMinInstead'); },
    get setGenMinOnFieldCopy(): string { return get('setGenMinOnFieldCopy'); },
    get setGenLock(): string { return get('setGenLock'); },
    get setGenLockMinimize(): string { return get('setGenLockMinimize'); },
    get setGenLockCopy(): string { return get('setGenLockCopy'); },
    get setGenLockAutoType(): string { return get('setGenLockAutoType'); },
    get setGenLockOrSleep(): string { return get('setGenLockOrSleep'); },
    get setGenStorage(): string { return get('setGenStorage'); },
    get setGenDisableOfflineStorage(): string { return get('setGenDisableOfflineStorage'); },
    get setGenShortLivedStorageToken(): string { return get('setGenShortLivedStorageToken'); },
    get setGenStorageLogout(): string { return get('setGenStorageLogout'); },
    get setGenShowAdvanced(): string { return get('setGenShowAdvanced'); },
    get setGenDevTools(): string { return get('setGenDevTools'); },
    get setGenTryBeta(): string { return get('setGenTryBeta'); },
    get setGenTryBetaWarning(): string { return get('setGenTryBetaWarning'); },
    get setGenTryBetaWarningBody(): string { return get('setGenTryBetaWarningBody'); },
    get setGenShowAppLogs(): string { return get('setGenShowAppLogs'); },
    get setGenReloadApp(): string { return get('setGenReloadApp'); },
    get setGenFieldLabelDblClickAutoType(): string { return get('setGenFieldLabelDblClickAutoType'); },
    get setGenTouchId(): string { return get('setGenTouchId'); },
    get setGenTouchIdDisabled(): string { return get('setGenTouchIdDisabled'); },
    get setGenTouchIdMemory(): string { return get('setGenTouchIdMemory'); },
    get setGenTouchIdFile(): string { return get('setGenTouchIdFile'); },
    get setGenTouchIdPass(): string { return get('setGenTouchIdPass'); },
    get setGenAudit(): string { return get('setGenAudit'); },
    get setGenAuditPasswords(): string { return get('setGenAuditPasswords'); },
    get setGenAuditPasswordEntropy(): string { return get('setGenAuditPasswordEntropy'); },
    get setGenExcludePinsFromAudit(): string { return get('setGenExcludePinsFromAudit'); },
    setGenCheckPasswordsOnHIBP: withReplace('setGenCheckPasswordsOnHIBP'),
    setGenHelpHIBP: withReplace('setGenHelpHIBP'),
    get setGenHelpHIBPLink(): string { return get('setGenHelpHIBPLink'); },
    get setGenAuditPasswordAge(): string { return get('setGenAuditPasswordAge'); },
    get setGenAuditPasswordAgeOff(): string { return get('setGenAuditPasswordAgeOff'); },
    get setGenAuditPasswordAgeOneYear(): string { return get('setGenAuditPasswordAgeOneYear'); },
    setGenAuditPasswordAgeYears: withReplace('setGenAuditPasswordAgeYears'),
    get setFilePath(): string { return get('setFilePath'); },
    setFileStorage: withReplace('setFileStorage'),
    get setFileIntl(): string { return get('setFileIntl'); },
    get setFileLocalHint(): string { return get('setFileLocalHint'); },
    get setFileDownloadApp(): string { return get('setFileDownloadApp'); },
    get setFileSave(): string { return get('setFileSave'); },
    get setFileSaveTo(): string { return get('setFileSaveTo'); },
    get setFileClose(): string { return get('setFileClose'); },
    get setFileSync(): string { return get('setFileSync'); },
    get setFileSyncVerb(): string { return get('setFileSyncVerb'); },
    get setFileSaveToXml(): string { return get('setFileSaveToXml'); },
    get setFileSaveToHtml(): string { return get('setFileSaveToHtml'); },
    get setFileLastSync(): string { return get('setFileLastSync'); },
    get setFileLastSyncUnknown(): string { return get('setFileLastSyncUnknown'); },
    get setFileSyncInProgress(): string { return get('setFileSyncInProgress'); },
    get setFileSyncError(): string { return get('setFileSyncError'); },
    get setFilePass(): string { return get('setFilePass'); },
    get setFileConfirmPass(): string { return get('setFileConfirmPass'); },
    get setFilePassChange(): string { return get('setFilePassChange'); },
    get setFilePassChanged(): string { return get('setFilePassChanged'); },
    get setFilePassNotMatch(): string { return get('setFilePassNotMatch'); },
    get setFileKeyFile(): string { return get('setFileKeyFile'); },
    get setFileSelKeyFile(): string { return get('setFileSelKeyFile'); },
    get setFileNames(): string { return get('setFileNames'); },
    get setFileDefUser(): string { return get('setFileDefUser'); },
    get setFileEnableTrash(): string { return get('setFileEnableTrash'); },
    get setFileHistMode(): string { return get('setFileHistMode'); },
    get setFileHistLimited(): string { return get('setFileHistLimited'); },
    get setFileHistDisabled(): string { return get('setFileHistDisabled'); },
    get setFileHistUnlimited(): string { return get('setFileHistUnlimited'); },
    get setFileHistLen(): string { return get('setFileHistLen'); },
    get setFileHistSize(): string { return get('setFileHistSize'); },
    get setFileBackups(): string { return get('setFileBackups'); },
    get setFileBackupEnable(): string { return get('setFileBackupEnable'); },
    get setFileBackupPath(): string { return get('setFileBackupPath'); },
    get setFileBackupTime(): string { return get('setFileBackupTime'); },
    get setFileBackupNow(): string { return get('setFileBackupNow'); },
    get setFileBackupNowWorking(): string { return get('setFileBackupNowWorking'); },
    get setFileBackupError(): string { return get('setFileBackupError'); },
    get setFileBackupErrorDescription(): string { return get('setFileBackupErrorDescription'); },
    get setFileBackupErrorIsDir(): string { return get('setFileBackupErrorIsDir'); },
    get setFileBackupErrorIsDirDescription(): string { return get('setFileBackupErrorIsDirDescription'); },
    get setFileBackupOnSave(): string { return get('setFileBackupOnSave'); },
    get setFileBackupDaily(): string { return get('setFileBackupDaily'); },
    get setFileBackupWeekly(): string { return get('setFileBackupWeekly'); },
    get setFileBackupMonthly(): string { return get('setFileBackupMonthly'); },
    get setFileBackupManually(): string { return get('setFileBackupManually'); },
    get setFileRounds(): string { return get('setFileRounds'); },
    get setFileKdfParams(): string { return get('setFileKdfParams'); },
    get setFileKdfParamsIter(): string { return get('setFileKdfParamsIter'); },
    get setFileKdfParamsMem(): string { return get('setFileKdfParamsMem'); },
    get setFileKdfParamsPar(): string { return get('setFileKdfParamsPar'); },
    get setFileKeyChangeForce(): string { return get('setFileKeyChangeForce'); },
    get setFileUseKeyFile(): string { return get('setFileUseKeyFile'); },
    get setFileUseGenKeyFile(): string { return get('setFileUseGenKeyFile'); },
    get setFileUseOldKeyFile(): string { return get('setFileUseOldKeyFile'); },
    get setFileGenKeyFile(): string { return get('setFileGenKeyFile'); },
    get setFileDontUseKeyFile(): string { return get('setFileDontUseKeyFile'); },
    get setFileEmptyPass(): string { return get('setFileEmptyPass'); },
    get setFileEmptyPassBody(): string { return get('setFileEmptyPassBody'); },
    get setFileSaveError(): string { return get('setFileSaveError'); },
    get setFileSaveErrorBody(): string { return get('setFileSaveErrorBody'); },
    get setFileAlreadyExists(): string { return get('setFileAlreadyExists'); },
    setFileAlreadyExistsBody: withReplace('setFileAlreadyExistsBody'),
    get setFileUnsaved(): string { return get('setFileUnsaved'); },
    get setFileUnsavedBody(): string { return get('setFileUnsavedBody'); },
    get setFileCloseNoSave(): string { return get('setFileCloseNoSave'); },
    get setFileDontClose(): string { return get('setFileDontClose'); },
    get setFileFormatVersion(): string { return get('setFileFormatVersion'); },
    get setFileExportRaw(): string { return get('setFileExportRaw'); },
    get setFileExportRawBody(): string { return get('setFileExportRawBody'); },
    setFileDeviceIntro: withReplace('setFileDeviceIntro'),
    get setFileDeviceSettings(): string { return get('setFileDeviceSettings'); },
    get setFileYubiKey(): string { return get('setFileYubiKey'); },
    get setFileDontUseYubiKey(): string { return get('setFileDontUseYubiKey'); },
    get setFileRefreshYubiKeyList(): string { return get('setFileRefreshYubiKeyList'); },
    get setFileYubiKeyHeader(): string { return get('setFileYubiKeyHeader'); },
    get setFileYubiKeyBody(): string { return get('setFileYubiKeyBody'); },
    get setFileYubiKeyErrorEmptyMac(): string { return get('setFileYubiKeyErrorEmptyMac'); },
    get setShTitle(): string { return get('setShTitle'); },
    get setShShowAll(): string { return get('setShShowAll'); },
    get setShColors(): string { return get('setShColors'); },
    get setShTrash(): string { return get('setShTrash'); },
    get setShFind(): string { return get('setShFind'); },
    get setShClearSearch(): string { return get('setShClearSearch'); },
    get setShCopyPass(): string { return get('setShCopyPass'); },
    get setShCopyUser(): string { return get('setShCopyUser'); },
    get setShCopyUrl(): string { return get('setShCopyUrl'); },
    get setShAutoType(): string { return get('setShAutoType'); },
    get setShPrev(): string { return get('setShPrev'); },
    get setShNext(): string { return get('setShNext'); },
    get setShCreateEntry(): string { return get('setShCreateEntry'); },
    get setShOpen(): string { return get('setShOpen'); },
    get setShSave(): string { return get('setShSave'); },
    get setShGen(): string { return get('setShGen'); },
    get setShSet(): string { return get('setShSet'); },
    get setShCopyPassGlobal(): string { return get('setShCopyPassGlobal'); },
    get setShCopyOtp(): string { return get('setShCopyOtp'); },
    get setShAutoTypeGlobal(): string { return get('setShAutoTypeGlobal'); },
    get setShCopyPassOnly(): string { return get('setShCopyPassOnly'); },
    setShRestoreApp: withReplace('setShRestoreApp'),
    get setShGlobal(): string { return get('setShGlobal'); },
    get setShLock(): string { return get('setShLock'); },
    get setShEdit(): string { return get('setShEdit'); },
    get setPlInstallTitle(): string { return get('setPlInstallTitle'); },
    get setPlInstallDesc(): string { return get('setPlInstallDesc'); },
    get setPlInstallLabel(): string { return get('setPlInstallLabel'); },
    get setPlInstallBtn(): string { return get('setPlInstallBtn'); },
    get setPlInstallBtnProgress(): string { return get('setPlInstallBtnProgress'); },
    get setPlUninstallBtn(): string { return get('setPlUninstallBtn'); },
    get setPlDisableBtn(): string { return get('setPlDisableBtn'); },
    get setPlEnableBtn(): string { return get('setPlEnableBtn'); },
    get setPlUpdateBtn(): string { return get('setPlUpdateBtn'); },
    get setPlLocaleBtn(): string { return get('setPlLocaleBtn'); },
    get setPlThemeBtn(): string { return get('setPlThemeBtn'); },
    get setPlJs(): string { return get('setPlJs'); },
    get setPlCss(): string { return get('setPlCss'); },
    get setPlLoc(): string { return get('setPlLoc'); },
    setPlCreatedBy: withReplace('setPlCreatedBy'),
    setPlLoadTime: withReplace('setPlLoadTime'),
    get setPlLastUpdate(): string { return get('setPlLastUpdate'); },
    get setPlLoadError(): string { return get('setPlLoadError'); },
    get setPlGalleryLoading(): string { return get('setPlGalleryLoading'); },
    get setPlGalleryLoadError(): string { return get('setPlGalleryLoadError'); },
    get setPlInstallUrlTitle(): string { return get('setPlInstallUrlTitle'); },
    get setPlInstallUrlDesc(): string { return get('setPlInstallUrlDesc'); },
    get setPlOfficial(): string { return get('setPlOfficial'); },
    get setPlSearch(): string { return get('setPlSearch'); },
    get setPlDevelop(): string { return get('setPlDevelop'); },
    get setPlDevelopStart(): string { return get('setPlDevelopStart'); },
    setPlTranslate: withReplace('setPlTranslate'),
    get setPlTranslateLink(): string { return get('setPlTranslateLink'); },
    get setPlAutoUpdate(): string { return get('setPlAutoUpdate'); },
    get setPlLoadGallery(): string { return get('setPlLoadGallery'); },
    get setBrowserTitle(): string { return get('setBrowserTitle'); },
    get setBrowserIntroDesktop(): string { return get('setBrowserIntroDesktop'); },
    get setBrowserIntroKeeWebConnect(): string { return get('setBrowserIntroKeeWebConnect'); },
    get setBrowserIntroKeePassXcBrowser(): string { return get('setBrowserIntroKeePassXcBrowser'); },
    get setBrowserIntroWeb(): string { return get('setBrowserIntroWeb'); },
    get setBrowserNotEnabled(): string { return get('setBrowserNotEnabled'); },
    get setBrowserEnablePerBrowser(): string { return get('setBrowserEnablePerBrowser'); },
    get setBrowserFocusIfLocked(): string { return get('setBrowserFocusIfLocked'); },
    get setBrowserFocusIfEmpty(): string { return get('setBrowserFocusIfEmpty'); },
    get setBrowserOtherBrowsers(): string { return get('setBrowserOtherBrowsers'); },
    setBrowserExtensionFor: withReplace('setBrowserExtensionFor'),
    get setBrowserExtensionNotSupported(): string { return get('setBrowserExtensionNotSupported'); },
    get setBrowserExtensionHelp(): string { return get('setBrowserExtensionHelp'); },
    get setBrowserExtensionInstall(): string { return get('setBrowserExtensionInstall'); },
    setBrowserExtensionKPXCWarnHeader: withReplace('setBrowserExtensionKPXCWarnHeader'),
    setBrowserExtensionKPXCWarnBody1: withReplace('setBrowserExtensionKPXCWarnBody1'),
    get setBrowserExtensionKPXCWarnBody2(): string { return get('setBrowserExtensionKPXCWarnBody2'); },
    get setBrowserSessions(): string { return get('setBrowserSessions'); },
    get setBrowserSessionsEmpty(): string { return get('setBrowserSessionsEmpty'); },
    get setBrowserSessionsIntro(): string { return get('setBrowserSessionsIntro'); },
    get setBrowserSessionsActiveTooltip(): string { return get('setBrowserSessionsActiveTooltip'); },
    get setBrowserSessionsActiveText(): string { return get('setBrowserSessionsActiveText'); },
    get setBrowserSessionsInactiveTooltip(): string { return get('setBrowserSessionsInactiveTooltip'); },
    get setBrowserSessionsInactiveText(): string { return get('setBrowserSessionsInactiveText'); },
    get setBrowserSessionsDeniedTooltip(): string { return get('setBrowserSessionsDeniedTooltip'); },
    get setBrowserSessionsDeniedText(): string { return get('setBrowserSessionsDeniedText'); },
    get setBrowserSessionsConnectedDate(): string { return get('setBrowserSessionsConnectedDate'); },
    get setBrowserSessionsTerminate(): string { return get('setBrowserSessionsTerminate'); },
    get setBrowserSessionsAccessToFiles(): string { return get('setBrowserSessionsAccessToFiles'); },
    get setBrowserSessionsNoFileAccess(): string { return get('setBrowserSessionsNoFileAccess'); },
    get setBrowserSessionsPasswordsRead(): string { return get('setBrowserSessionsPasswordsRead'); },
    get setBrowserSessionsPasswordsWritten(): string { return get('setBrowserSessionsPasswordsWritten'); },
    get setDevicesTitle(): string { return get('setDevicesTitle'); },
    get setDevicesEnableUsb(): string { return get('setDevicesEnableUsb'); },
    setDevicesYubiKeyIntro: withReplace('setDevicesYubiKeyIntro'),
    get setDevicesYubiKeyIntroLink(): string { return get('setDevicesYubiKeyIntroLink'); },
    setDevicesYubiKeyToolsDesc: withReplace('setDevicesYubiKeyToolsDesc'),
    setDevicesYubiKeyToolsDesc2: withReplace('setDevicesYubiKeyToolsDesc2'),
    get setDevicesYubiKeyToolsDescLink(): string { return get('setDevicesYubiKeyToolsDescLink'); },
    setDevicesYubiKeyToolsStatusChecking: withReplace('setDevicesYubiKeyToolsStatusChecking'),
    setDevicesYubiKeyToolsStatusOk: withReplace('setDevicesYubiKeyToolsStatusOk'),
    setDevicesYubiKeyToolsStatusError: withReplace('setDevicesYubiKeyToolsStatusError'),
    get setDevicesYubiKeyOtpTitle(): string { return get('setDevicesYubiKeyOtpTitle'); },
    get setDevicesYubiKeyOtpDesc(): string { return get('setDevicesYubiKeyOtpDesc'); },
    get setDevicesYubiKeyOtpShowIcon(): string { return get('setDevicesYubiKeyOtpShowIcon'); },
    get setDevicesYubiKeyOtpAutoOpen(): string { return get('setDevicesYubiKeyOtpAutoOpen'); },
    get setDevicesYubiKeyOtpMatchEntries(): string { return get('setDevicesYubiKeyOtpMatchEntries'); },
    get setDevicesYubiKeyChalRespTitle(): string { return get('setDevicesYubiKeyChalRespTitle'); },
    get setDevicesYubiKeyChalRespDesc(): string { return get('setDevicesYubiKeyChalRespDesc'); },
    get setDevicesYubiKeyChalRespShow(): string { return get('setDevicesYubiKeyChalRespShow'); },
    get setDevicesYubiKeyStuckWorkaround(): string { return get('setDevicesYubiKeyStuckWorkaround'); },
    get setDevicesYubiKeyRememberChalResp(): string { return get('setDevicesYubiKeyRememberChalResp'); },
    get setAboutTitle(): string { return get('setAboutTitle'); },
    get setAboutBuilt(): string { return get('setAboutBuilt'); },
    get setAboutLic(): string { return get('setAboutLic'); },
    get setAboutLicComment(): string { return get('setAboutLicComment'); },
    setAboutFirst: withReplace('setAboutFirst'),
    setAboutSecond: withReplace('setAboutSecond'),
    setAboutSource: withReplace('setAboutSource'),
    get setHelpFormat(): string { return get('setHelpFormat'); },
    setHelpFormatBody: withReplace('setHelpFormatBody'),
    get setHelpProblems(): string { return get('setHelpProblems'); },
    setHelpProblems1: withReplace('setHelpProblems1'),
    setHelpProblems2: withReplace('setHelpProblems2'),
    get setHelpOpenIssue(): string { return get('setHelpOpenIssue'); },
    get setHelpContactLink(): string { return get('setHelpContactLink'); },
    get setHelpAppInfo(): string { return get('setHelpAppInfo'); },
    get setHelpOtherPlatforms(): string { return get('setHelpOtherPlatforms'); },
    get setHelpDesktopApps(): string { return get('setHelpDesktopApps'); },
    get setHelpWebApp(): string { return get('setHelpWebApp'); },
    get setHelpUpdates(): string { return get('setHelpUpdates'); },
    get setHelpTwitter(): string { return get('setHelpTwitter'); },
    get dropboxSetupDesc(): string { return get('dropboxSetupDesc'); },
    get dropboxAppKey(): string { return get('dropboxAppKey'); },
    get dropboxAppKeyDesc(): string { return get('dropboxAppKeyDesc'); },
    get dropboxAppKeyHint(): string { return get('dropboxAppKeyHint'); },
    get dropboxAppSecret(): string { return get('dropboxAppSecret'); },
    get dropboxAppSecretDesc(): string { return get('dropboxAppSecretDesc'); },
    get dropboxFolder(): string { return get('dropboxFolder'); },
    get dropboxFolderDesc(): string { return get('dropboxFolderDesc'); },
    get dropboxFolderSettingsDesc(): string { return get('dropboxFolderSettingsDesc'); },
    get dropboxFolderPlaceholder(): string { return get('dropboxFolderPlaceholder'); },
    get dropboxLink(): string { return get('dropboxLink'); },
    get dropboxLinkApp(): string { return get('dropboxLinkApp'); },
    get dropboxLinkFull(): string { return get('dropboxLinkFull'); },
    get dropboxLinkCustom(): string { return get('dropboxLinkCustom'); },
    get gdriveSharedWithMe(): string { return get('gdriveSharedWithMe'); },
    get gdriveSharedDrives(): string { return get('gdriveSharedDrives'); },
    get webdavSaveMethod(): string { return get('webdavSaveMethod'); },
    get webdavSaveMove(): string { return get('webdavSaveMove'); },
    get webdavSavePut(): string { return get('webdavSavePut'); },
    get webdavNoLastModified(): string { return get('webdavNoLastModified'); },
    get webdavStatReload(): string { return get('webdavStatReload'); },
    get launcherSave(): string { return get('launcherSave'); },
    get launcherFileFilter(): string { return get('launcherFileFilter'); },
    get authPopupRequired(): string { return get('authPopupRequired'); },
    get authPopupRequiredBody(): string { return get('authPopupRequiredBody'); },
    get exportFileInfo(): string { return get('exportFileInfo'); },
    get exportHtmlName(): string { return get('exportHtmlName'); },
    get exportHtmlDate(): string { return get('exportHtmlDate'); },
    get exportGenerator(): string { return get('exportGenerator'); },
    exportDescription: withReplace('exportDescription'),
    get exportEntries(): string { return get('exportEntries'); },
    get importCsvTitle(): string { return get('importCsvTitle'); },
    get importCsvRun(): string { return get('importCsvRun'); },
    get importIgnoreField(): string { return get('importIgnoreField'); },
    get importTo(): string { return get('importTo'); },
    get importNewFile(): string { return get('importNewFile'); },
    get yubiKeyStuckError(): string { return get('yubiKeyStuckError'); },
    get yubiKeyNoKeyHeader(): string { return get('yubiKeyNoKeyHeader'); },
    yubiKeyNoKeyBody: withReplace('yubiKeyNoKeyBody'),
    get yubiKeySlot(): string { return get('yubiKeySlot'); },
    get yubiKeyTouchRequestedHeader(): string { return get('yubiKeyTouchRequestedHeader'); },
    yubiKeyTouchRequestedBody: withReplace('yubiKeyTouchRequestedBody'),
    get yubiKeyDisabledErrorHeader(): string { return get('yubiKeyDisabledErrorHeader'); },
    get yubiKeyDisabledErrorBody(): string { return get('yubiKeyDisabledErrorBody'); },
    yubiKeyErrorWithCode: withReplace('yubiKeyErrorWithCode'),
    bioOpenAuthPrompt: withReplace('bioOpenAuthPrompt'),
    get extensionErrorNoOpenFiles(): string { return get('extensionErrorNoOpenFiles'); },
    get extensionErrorUserRejected(): string { return get('extensionErrorUserRejected'); },
    get extensionErrorNoMatches(): string { return get('extensionErrorNoMatches'); },
    get extensionErrorAlertDisplayed(): string { return get('extensionErrorAlertDisplayed'); },
    get extensionConnectHeader(): string { return get('extensionConnectHeader'); },
    extensionConnectIntro: withReplace('extensionConnectIntro'),
    get extensionConnectUnknownActivity(): string { return get('extensionConnectUnknownActivity'); },
    get extensionConnectFiles(): string { return get('extensionConnectFiles'); },
    get extensionConnectAllOtherFiles(): string { return get('extensionConnectAllOtherFiles'); },
    get extensionConnectAllFiles(): string { return get('extensionConnectAllFiles'); },
    get extensionConnectAskGet(): string { return get('extensionConnectAskGet'); },
    get extensionConnectAskGetMultiple(): string { return get('extensionConnectAskGetMultiple'); },
    get extensionConnectAskGetAlways(): string { return get('extensionConnectAskGetAlways'); },
    get extensionConnectAskSave(): string { return get('extensionConnectAskSave'); },
    get extensionConnectAskSaveAlways(): string { return get('extensionConnectAskSaveAlways'); },
    get extensionConnectAskSaveAuto(): string { return get('extensionConnectAskSaveAuto'); },
    get extensionConnectSettingsAreForSession(): string { return get('extensionConnectSettingsAreForSession'); },
    get extensionUnlockMessage(): string { return get('extensionUnlockMessage'); },
    get extensionNewGroupHeader(): string { return get('extensionNewGroupHeader'); },
    extensionNewGroupBody: withReplace('extensionNewGroupBody'),
    get extensionNewGroupPath(): string { return get('extensionNewGroupPath'); },
    get extensionNewGroupFile(): string { return get('extensionNewGroupFile'); },
    get extensionSaveEntryHeader(): string { return get('extensionSaveEntryHeader'); },
    extensionSaveEntryBody: withReplace('extensionSaveEntryBody'),
    get extensionSaveEntryAuto(): string { return get('extensionSaveEntryAuto'); },
    get extensionSaveEntryNewGroup(): string { return get('extensionSaveEntryNewGroup'); },
    extensionSelectPasswordFor: withReplace('extensionSelectPasswordFor'),
    get selectEntryHeader(): string { return get('selectEntryHeader'); },
    get selectEntryEnterHint(): string { return get('selectEntryEnterHint'); },
    get selectEntryTypingHint(): string { return get('selectEntryTypingHint'); },
    get selectEntryContains(): string { return get('selectEntryContains'); },
    get selectEntrySubdomains(): string { return get('selectEntrySubdomains'); },
    get selectEntryFieldHeader(): string { return get('selectEntryFieldHeader'); },
    get selectEntryFieldTouch(): string { return get('selectEntryFieldTouch'); }
    // end of generated code
};

export type LocaleKey = Exclude<keyof typeof Locale, 'set' | 'get' | 'localeName'>;
